@@ -27,11 +27,11 @@ Moonshine::Test - Test!
 
 =head1 VERSION
 
-Version 0.12
+Version 0.13
 
 =cut
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 =head1 SYNOPSIS
 
@@ -136,6 +136,8 @@ moon_test_one can currently run the following tests.
 
 =item ref_index_like - like - ''
 
+=item ref_index_obj - isa_ok - ''
+
 =item list_key_scalar - is - '' (requires key)
 
 =item list_key_ref - is_deeply - [] or {} (requires key)
@@ -146,8 +148,14 @@ moon_test_one can currently run the following tests.
 
 =item list_index_ref - is_deeply - [] or {} (required index)
 
+=item list_index_obj - isa_ok - ''
+
 =item list_index_like - like - ''
 
+=item count - is - ''
+
+=item count_ref - is - ''
+
 =item skip - ok(1)
 
 =back
@@ -307,6 +315,18 @@ sub moon_test_one {
 "No index passed to test - ref_index_like - testing - $test_name"
               );
         }
+        when ('ref_index_obj') {
+            return exists $instruction{index}
+              ? isa_ok(
+                $test[0]->[ $instruction{index} ],
+                $expected[0],
+"$test_name is ref - has obj index: $instruction{index} - isa_ok - $expected[0]"
+              )
+              : ok(
+                0,
+"No index passed to test - ref_index_obj - testing - $test_name"
+              );
+        }
         when ('list_index_scalar') {
             return exists $instruction{index}
               ? is(
@@ -343,6 +363,18 @@ sub moon_test_one {
 "No index passed to test - list_index_like - testing - $test_name"
               );
         }
+        when ('list_index_obj') {
+             return exists $instruction{index}
+              ? isa_ok(
+                $test[ $instruction{index} ],
+                $expected[0],
+"$test_name is list - has obj index: $instruction{index} - isa_ok - $expected[0]"
+              )
+              : ok(
+                0,
+"No index passed to test - list_index_obj - testing - $test_name"
+              );
+        }
         when ('list_key_scalar') {
             return exists $instruction{key}
               ? is(
@@ -377,6 +409,20 @@ sub moon_test_one {
                 "No key passed to test - list_key_like - testing - $test_name"
               );
         }
+        when ('count') {
+             return is(
+                scalar @test,
+                $expected[0],
+"$test_name is list - count - is - $expected[0]"
+              );
+        }
+        when ('count_ref') {
+             return is(
+                scalar @{ $test[0] },
+                $expected[0],
+"$test_name is ref - count - is - $expected[0]"
+              );
+        }
         when ('scalar') {
             return is( $test[0], $expected[0], sprintf "%s is scalar - is - %s",
                 $test_name, $expected[0] );
@@ -519,7 +565,7 @@ sub moon_test {
         params => \@_,
         spec   => {
             build        => { type => HASHREF, optional => 1, },
-            instance     => { type => HASHREF, optional => 1, },
+            instance     => { optional => 1, },
             instructions => { type => ARRAYREF },
             name         => { type => SCALAR },
         }
